# Agent Environment

[![Release](https://img.shields.io/github/v/release/Wh1isper/y-agent-environment)](https://img.shields.io/github/v/release/Wh1isper/y-agent-environment)
[![Build status](https://img.shields.io/github/actions/workflow/status/Wh1isper/y-agent-environment/main.yml?branch=main)](https://github.com/Wh1isper/y-agent-environment/actions/workflows/main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/Wh1isper/y-agent-environment/branch/main/graph/badge.svg)](https://codecov.io/gh/Wh1isper/y-agent-environment)
[![Commit activity](https://img.shields.io/github/commit-activity/m/Wh1isper/y-agent-environment)](https://img.shields.io/github/commit-activity/m/Wh1isper/y-agent-environment)
[![License](https://img.shields.io/github/license/Wh1isper/y-agent-environment)](https://img.shields.io/github/license/Wh1isper/y-agent-environment)

Environmental Abstraction for the General Agent.
